==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/EditorCellInfoDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { CellInfoDescription } from "./CellInfoDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let EditorCellInfoDescription = /*@__PURE__*/ (() => {
    class EditorCellInfoDescription extends CellInfoDescription {
        constructor() {
            super();
            this.fl = null;
            this.fr = null;
            this.fx = null;
            this.fw = null;
            this.fv = null;
            this.ft = null;
            this.fu = null;
            this.fj = null;
            this.fs = null;
            this.fo = false;
        }
        get_type() {
            return "EditorCellInfo";
        }
        get editTarget() {
            return this.fl;
        }
        set editTarget(a) {
            this.fl = a;
            this.e("EditTarget");
        }
        get dataType() {
            return this.fr;
        }
        set dataType(a) {
            this.fr = a;
            this.e("DataType");
        }
        get errorMessage() {
            return this.fx;
        }
        set errorMessage(a) {
            this.fx = a;
            this.e("ErrorMessage");
        }
        get editValueRef() {
            return this.fw;
        }
        set editValueRef(a) {
            this.fw = a;
            this.e("EditValueRef");
        }
        get editorType() {
            return this.fv;
        }
        set editorType(a) {
            this.fv = a;
            this.e("EditorType");
        }
        get editorDataSourceRef() {
            return this.ft;
        }
        set editorDataSourceRef(a) {
            this.ft = a;
            this.e("EditorDataSourceRef");
        }
        get editorTextField() {
            return this.fu;
        }
        set editorTextField(a) {
            this.fu = a;
            this.e("EditorTextField");
        }
        get editorValueField() {
            return this.fj;
        }
        set editorValueField(a) {
            this.fj = a;
            this.e("EditorValueField");
        }
        get dateFormatString() {
            return this.fs;
        }
        set dateFormatString(a) {
            this.fs = a;
            this.e("DateFormatString");
        }
        get showTodayButton() {
            return this.fo;
        }
        set showTodayButton(a) {
            this.fo = a;
            this.e("ShowTodayButton");
        }
    }
    EditorCellInfoDescription.$t = /*@__PURE__*/ markType(EditorCellInfoDescription, 'EditorCellInfoDescription', CellInfoDescription.$);
    EditorCellInfoDescription.__marshalByValue1 = true;
    EditorCellInfoDescription.__marshalByValueAlias1 = "EditorCellModel";
    return EditorCellInfoDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/EditorCellInfoDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { CellInfoDescription } from "./CellInfoDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let EditorCellInfoDescription = /*@__PURE__*/ (() => {
    class EditorCellInfoDescription extends CellInfoDescription {
        get_type() {
            return "EditorCellInfo";
        }
        constructor() {
            super();
            this.fn = null;
            this.ft = null;
            this.fz = null;
            this.fy = null;
            this.fx = null;
            this.fv = null;
            this.fw = null;
            this.fl = null;
            this.fu = null;
            this.fq = false;
        }
        get editTarget() {
            return this.fn;
        }
        set editTarget(a) {
            this.fn = a;
            this.g("EditTarget");
        }
        get dataType() {
            return this.ft;
        }
        set dataType(a) {
            this.ft = a;
            this.g("DataType");
        }
        get errorMessage() {
            return this.fz;
        }
        set errorMessage(a) {
            this.fz = a;
            this.g("ErrorMessage");
        }
        get editValueRef() {
            return this.fy;
        }
        set editValueRef(a) {
            this.fy = a;
            this.g("EditValueRef");
        }
        get editorType() {
            return this.fx;
        }
        set editorType(a) {
            this.fx = a;
            this.g("EditorType");
        }
        get editorDataSourceRef() {
            return this.fv;
        }
        set editorDataSourceRef(a) {
            this.fv = a;
            this.g("EditorDataSourceRef");
        }
        get editorTextField() {
            return this.fw;
        }
        set editorTextField(a) {
            this.fw = a;
            this.g("EditorTextField");
        }
        get editorValueField() {
            return this.fl;
        }
        set editorValueField(a) {
            this.fl = a;
            this.g("EditorValueField");
        }
        get dateFormatString() {
            return this.fu;
        }
        set dateFormatString(a) {
            this.fu = a;
            this.g("DateFormatString");
        }
        get showTodayButton() {
            return this.fq;
        }
        set showTodayButton(a) {
            this.fq = a;
            this.g("ShowTodayButton");
        }
    }
    EditorCellInfoDescription.$t = /*@__PURE__*/ markType(EditorCellInfoDescription, 'EditorCellInfoDescription', CellInfoDescription.$);
    EditorCellInfoDescription.__marshalByValue1 = true;
    EditorCellInfoDescription.__marshalByValueAlias1 = "EditorCellModel";
    return EditorCellInfoDescription;
})();
